[easytag] Improve many translatable strings, bug 689416



commit 1bc01d3528f38de16442df65abd5a282612ffab4
Author: David King <amigadave amigadave com>
Date:   Sun Dec 2 00:13:52 2012 +0000

    Improve many translatable strings, bug 689416
    
    Fix a large number of translatable strings, and plug a few memory leaks
    in the process.

 src/bar.c     |    6 ++--
 src/browser.c |    9 +++---
 src/cddb.c    |   73 +++++++++++++++++++++++++++++++++++++--------------
 src/easytag.c |   81 ++++++++++++++++++++++++++++-----------------------------
 src/et_core.c |    2 +-
 src/misc.c    |   18 ++++++++----
 src/prefs.c   |   25 ++++++++---------
 src/scan.c    |    2 +-
 src/vcedit.c  |    2 +-
 9 files changed, 128 insertions(+), 90 deletions(-)
---
diff --git a/src/browser.c b/src/browser.c
index f498e2b..c1fa161 100644
--- a/src/browser.c
+++ b/src/browser.c
@@ -3033,7 +3033,7 @@ GtkWidget *Create_Browser_Items (GtkWidget *parent)
     gchar *BrowserTree_Titles[] = {N_("Tree")};
     gchar *BrowserList_Titles[] = {N_("File Name"),N_("Title"),N_("Artist"),N_("Album Artist"),N_("Album"),
                                    N_("Year"),N_("Track"),N_("Genre"),N_("Comment"),
-                                   N_("Composer"),N_("Orig. Artist"),N_("Copyright"),
+                                   N_("Composer"),N_("Original Artist"),N_("Copyright"),
                                    N_("URL"),N_("Encoded By")};
     gchar *ArtistList_Titles[]  = {N_("Artist"),N_("# Albums"),N_("# Files")};
     gchar *AlbumList_Titles[]   = {N_("Album"),N_("# Files")};
@@ -3088,7 +3088,8 @@ GtkWidget *Create_Browser_Items (GtkWidget *parent)
     /*
      * The label for displaying number of files in path (without subdirs)
      */
-    BrowserLabel = gtk_label_new(_("â file(s)"));
+    /* Translators: No files, as in "0 files". */
+    BrowserLabel = gtk_label_new(_("No files"));
     gtk_box_pack_start(GTK_BOX(HBox),BrowserLabel,FALSE,FALSE,2);
 
 
@@ -3708,7 +3709,7 @@ void Browser_Open_Rename_Directory_Window (void)
     gtk_container_add(GTK_CONTAINER(Frame),VBox);
     gtk_container_set_border_width(GTK_CONTAINER(VBox), 4);
 
-    string = g_strdup_printf(_("Rename the directory '%s' to : "),directory_name_utf8);
+    string = g_strdup_printf(_("Rename the directory '%s' to:"),directory_name_utf8);
     Label = gtk_label_new(_(string));
     g_free(string);
     gtk_box_pack_start(GTK_BOX(VBox),Label,FALSE,TRUE,0);
@@ -4056,7 +4057,7 @@ void Rename_Directory (void)
                                            tmp_path_utf8,
                                            new_path_utf8);
         gtk_message_dialog_format_secondary_text(GTK_MESSAGE_DIALOG(msgdialog),"%s",g_strerror(errno));
-        gtk_window_set_title(GTK_WINDOW(msgdialog),_("Directory Rename Error"));
+        gtk_window_set_title(GTK_WINDOW(msgdialog),_("Rename Directory Error"));
 
         gtk_dialog_run(GTK_DIALOG(msgdialog));
         gtk_widget_destroy(msgdialog);
diff --git a/src/cddb.c b/src/cddb.c
index 4feccea..0afb780 100644
--- a/src/cddb.c
+++ b/src/cddb.c
@@ -225,7 +225,7 @@ void Open_Cddb_Window (void)
     GtkWidget *ScrollWindow;
     GtkWidget *Icon;
     gchar *CddbAlbumList_Titles[] = { NULL, N_("Artist / Album"), N_("Category")}; // Note: don't set "" instead of NULL else this will cause problem with translation language
-    gchar *CddbTrackList_Titles[] = { "#", N_("Track Name"), N_("Time")};
+    gchar *CddbTrackList_Titles[] = { "#", N_("Track Name"), N_("Duration")};
     GtkCellRenderer* renderer;
     GtkTreeViewColumn* column;
     GtkAllocation allocation = { 0,0,0,0 };
@@ -236,7 +236,7 @@ void Open_Cddb_Window (void)
         return;
     }
     CddbWindow = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-    gtk_window_set_title(GTK_WINDOW(CddbWindow),_("CD Data Base Search"));
+    gtk_window_set_title(GTK_WINDOW(CddbWindow),_("CD Database Search"));
     gtk_window_set_position(GTK_WINDOW(CddbWindow),GTK_WIN_POS_CENTER);
 
     // This part is needed to set correctly the position of handle panes
@@ -280,7 +280,7 @@ void Open_Cddb_Window (void)
     hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL,4);
     gtk_box_pack_start(GTK_BOX(notebookvbox),hbox,FALSE,FALSE,0);
 
-    Label = gtk_label_new(_("Request CD database :"));
+    Label = gtk_label_new(_("Request CD database:"));
     gtk_misc_set_alignment(GTK_MISC(Label),1.0,0.5);
     gtk_box_pack_start(GTK_BOX(hbox),Label,FALSE,FALSE,0);
 
@@ -370,7 +370,7 @@ void Open_Cddb_Window (void)
     hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL,4);
     gtk_box_pack_start(GTK_BOX(notebookvbox),hbox,FALSE,FALSE,0);
 
-    Label = gtk_label_new(_("Words :"));
+    Label = gtk_label_new(_("Words:"));
     gtk_misc_set_alignment(GTK_MISC(Label),1.0,0.5);
     gtk_box_pack_start(GTK_BOX(hbox),Label,FALSE,FALSE,0);
 
@@ -423,7 +423,7 @@ void Open_Cddb_Window (void)
     /*
      * Search options
      */
-    Frame = gtk_frame_new(_("Search In :"));
+    Frame = gtk_frame_new(_("Search In:"));
     gtk_box_pack_start(GTK_BOX(notebookvbox),Frame,FALSE,TRUE,0);
 
     Table = gtk_table_new(7,4,FALSE);
@@ -431,11 +431,21 @@ void Open_Cddb_Window (void)
     gtk_table_set_row_spacings(GTK_TABLE(Table),1);
     gtk_table_set_col_spacings(GTK_TABLE(Table),1);
 
+    /* Translators: This option is for the previous 'search in' option. For
+     * instance, translate this as "Search in:" "All fields". */
     CddbSearchInAllFields      = gtk_check_button_new_with_label(_("All Fields"));
     Separator                  = gtk_separator_new(GTK_ORIENTATION_VERTICAL);
+    /* Translators: This option is for the previous 'search in' option. For
+     * instance, translate this as "Search in:" "Artist". */
     CddbSearchInArtistField    = gtk_check_button_new_with_label(_("Artist"));
+    /* Translators: This option is for the previous 'search in' option. For
+     * instance, translate this as "Search in:" "Album". */
     CddbSearchInTitleField     = gtk_check_button_new_with_label(_("Album"));
+    /* Translators: This option is for the previous 'search in' option. For
+     * instance, translate this as "Search in:" "Track Name". */
     CddbSearchInTrackNameField = gtk_check_button_new_with_label(_("Track Name"));
+    /* Translators: This option is for the previous 'search in' option. For
+     * instance, translate this as "Search in:" "Other". */
     CddbSearchInOtherField     = gtk_check_button_new_with_label(_("Other"));
     gtk_table_attach(GTK_TABLE(Table),CddbSearchInAllFields,     0,1,0,1,GTK_FILL,GTK_FILL,0,0);
     gtk_table_attach(GTK_TABLE(Table),Separator,                 1,2,0,1,GTK_FILL,GTK_FILL,0,0);
@@ -458,17 +468,39 @@ void Open_Cddb_Window (void)
     CddbSeparatorH = gtk_separator_new(GTK_ORIENTATION_HORIZONTAL);
     gtk_table_attach(GTK_TABLE(Table),CddbSeparatorH,0,7,1,2,GTK_FILL,GTK_FILL,0,0);
 
+    /* Translators: This option is for the previous 'search in' option. For
+     * instance, translate this as "Search in:" "All Categories". */
     CddbSearchInAllCategories      = gtk_check_button_new_with_label(_("All Categories"));
     CddbSeparatorV                 = gtk_separator_new(GTK_ORIENTATION_VERTICAL);
+    /* Translators: This option is for the previous 'search in' option. For
+     * instance, translate this as "Search in:" "Blues". */
     CddbSearchInBluesCategory      = gtk_check_button_new_with_label(_("Blues"));
+    /* Translators: This option is for the previous 'search in' option. For
+     * instance, translate this as "Search in:" "Classical". */
     CddbSearchInClassicalCategory  = gtk_check_button_new_with_label(_("Classical"));
+    /* Translators: This option is for the previous 'search in' option. For
+     * instance, translate this as "Search in:" "Country". */
     CddbSearchInCountryCategory    = gtk_check_button_new_with_label(_("Country"));
+    /* Translators: This option is for the previous 'search in' option. For
+     * instance, translate this as "Search in:" "Folk". */
     CddbSearchInFolkCategory       = gtk_check_button_new_with_label(_("Folk"));
+    /* Translators: This option is for the previous 'search in' option. For
+     * instance, translate this as "Search in:" "Jazz". */
     CddbSearchInJazzCategory       = gtk_check_button_new_with_label(_("Jazz"));
-    CddbSearchInMiscCategory       = gtk_check_button_new_with_label(_("Misc"));
-    CddbSearchInNewageCategory     = gtk_check_button_new_with_label(_("Newage"));
+    /* Translators: This option is for the previous 'search in' option. For
+     * instance, translate this as "Search in:" "Misc". */
+    CddbSearchInMiscCategory       = gtk_check_button_new_with_label(_("Misc."));
+    /* Translators: This option is for the previous 'search in' option. For
+     * instance, translate this as "Search in:" "New age". */
+    CddbSearchInNewageCategory     = gtk_check_button_new_with_label(_("New Age"));
+    /* Translators: This option is for the previous 'search in' option. For
+     * instance, translate this as "Search in:" "Reggae". */
     CddbSearchInReggaeCategory     = gtk_check_button_new_with_label(_("Reggae"));
+    /* Translators: This option is for the previous 'search in' option. For
+     * instance, translate this as "Search in:" "Rock". */
     CddbSearchInRockCategory       = gtk_check_button_new_with_label(_("Rock"));
+    /* Translators: This option is for the previous 'search in' option. For
+     * instance, translate this as "Search in:" "Soundtrack". */
     CddbSearchInSoundtrackCategory = gtk_check_button_new_with_label(_("Soundtrack"));
     gtk_table_attach(GTK_TABLE(Table),CddbSearchInAllCategories,     0,1,2,4,GTK_FILL,GTK_FILL,0,0);
     gtk_table_attach(GTK_TABLE(Table),CddbSeparatorV,                1,2,2,4,GTK_FILL,GTK_FILL,0,0);
@@ -506,12 +538,12 @@ void Open_Cddb_Window (void)
     g_signal_connect(G_OBJECT(CddbSearchInReggaeCategory),    "toggled",G_CALLBACK(Cddb_Set_Search_Button_Sensivity),NULL);
     g_signal_connect(G_OBJECT(CddbSearchInRockCategory),      "toggled",G_CALLBACK(Cddb_Set_Search_Button_Sensivity),NULL);
     g_signal_connect(G_OBJECT(CddbSearchInSoundtrackCategory),"toggled",G_CALLBACK(Cddb_Set_Search_Button_Sensivity),NULL);
-    gtk_widget_set_tooltip_text(CddbSearchInRockCategory,_("included : funk, soul, rap, pop, industrial, metal, etc."));
+    gtk_widget_set_tooltip_text(CddbSearchInRockCategory,_("included: funk, soul, rap, pop, industrial, metal, etc."));
     gtk_widget_set_tooltip_text(CddbSearchInSoundtrackCategory,_("movies, shows"));
     gtk_widget_set_tooltip_text(CddbSearchInMiscCategory,_("others that do not fit in the above categories"));
 
     // Button to display/hide the categories
-    CddbShowCategoriesButton = gtk_toggle_button_new_with_label(_(" Categories "));
+    CddbShowCategoriesButton = gtk_toggle_button_new_with_label(_("Categories"));
     gtk_table_attach(GTK_TABLE(Table),CddbShowCategoriesButton,6,7,0,1,GTK_FILL,GTK_FILL,4,0);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(CddbShowCategoriesButton),CDDB_SHOW_CATEGORIES);
     g_signal_connect(G_OBJECT(CddbShowCategoriesButton),"toggled", G_CALLBACK(Cddb_Show_Categories_Button_Toggled),NULL);
@@ -519,7 +551,7 @@ void Open_Cddb_Window (void)
     /*
      * Results command
      */
-    Frame = gtk_frame_new(_("Results :"));
+    Frame = gtk_frame_new(_("Results:"));
     gtk_box_pack_start(GTK_BOX(VBox),Frame,FALSE,TRUE,0);
 
     hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL,4);
@@ -707,7 +739,7 @@ void Open_Cddb_Window (void)
     /*
      * Apply results to fields...
      */
-    Frame = gtk_frame_new(_("Set Into :"));
+    Frame = gtk_frame_new(_("Set Into:"));
     gtk_box_pack_start(GTK_BOX(VBox),Frame,FALSE,TRUE,0);
 
     vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL,2);
@@ -773,7 +805,7 @@ void Open_Cddb_Window (void)
     // it will not understand why the cddb results aren't loaded correctly...
     //gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(CddbUseDLM2),CDDB_USE_DLM);
     gtk_widget_set_tooltip_text(CddbUseDLM2,_("When activating this option, the "
-        "Levenshtein algorithm (DLM : Damerau-Levenshtein Metric) will be used "
+        "Levenshtein algorithm (DLM: Damerau-Levenshtein Metric) will be used "
         "to match the CDDB title against every file name in the current folder, "
         "and to select the best match. This will be used when selecting the "
         "corresponding audio file, or applying cddb results, instead of using "
@@ -2463,7 +2495,7 @@ gboolean Cddb_Search_Album_List_From_String_Freedb (void)
     if (web_search_disabled)
         msg = g_strdup_printf(_("Sorry, the web-based search is currently down!"));
     else
-        msg = g_strdup_printf(_("Found %d matching album(s)"),g_list_length(CddbAlbumList));
+        msg = g_strdup_printf(ngettext("Found one matching album","Found %d matching albums",g_list_length(CddbAlbumList)),g_list_length(CddbAlbumList));
     gtk_statusbar_push(GTK_STATUSBAR(CddbStatusBar),CddbStatusBarContext,msg);
     g_free(msg);
 
@@ -2808,7 +2840,7 @@ gboolean Cddb_Search_Album_List_From_String_Gnudb (void)
     gtk_widget_set_sensitive(GTK_WIDGET(CddbStopSearchButton),FALSE);
     gtk_widget_set_sensitive(GTK_WIDGET(CddbStopSearchAutoButton),FALSE);
 
-    msg = g_strdup_printf(_("Found %d matching album(s)"),num_albums);
+    msg = g_strdup_printf(ngettext("Found one matching album","Found %d matching albums",num_albums),num_albums);
     gtk_statusbar_push(GTK_STATUSBAR(CddbStatusBar),CddbStatusBarContext,msg);
     g_free(msg);
 
@@ -2918,7 +2950,7 @@ gboolean Cddb_Search_Album_From_Selected_Files (void)
         return FALSE;
     }else
     {
-        msg = g_strdup_printf(_("%d file(s) selected!"),file_selectedcount);
+        msg = g_strdup_printf(ngettext("One file selected","%d files selected",file_selectedcount),file_selectedcount);
         gtk_statusbar_push(GTK_STATUSBAR(CddbStatusBar),CddbStatusBarContext,msg);
         g_free(msg);
     }
@@ -2998,7 +3030,9 @@ gboolean Cddb_Search_Album_From_Selected_Files (void)
                                                    GTK_MESSAGE_ERROR,
                                                    GTK_BUTTONS_CLOSE,
                                                    "%s",
-                                                   _("The path for 'Local CD Data Base' was not defined"));
+                                                   _("The path for 'Local CD Database' was not defined"));
+                /* Translators: 'it' in this sentence refers to the local CD
+                 * database path. */
                 gtk_message_dialog_format_secondary_text(GTK_MESSAGE_DIALOG(msgdialog), "%s", _("Enter it in the preferences window before using this search."));
                 gtk_window_set_title(GTK_WINDOW(msgdialog),_("Local CD searchâ"));
 
@@ -3298,7 +3332,7 @@ gboolean Cddb_Search_Album_From_Selected_Files (void)
 
     }
 
-    msg = g_strdup_printf(_("Found %d matching album(s) for DiscID '%s'"), g_list_length(CddbAlbumList),cddb_discid);
+    msg = g_strdup_printf(ngettext("DiscID '%s' gave one matching album","DiscID '%s' gave %d matching albums",g_list_length(CddbAlbumList)),cddb_discid,g_list_length(CddbAlbumList));
     gtk_statusbar_push(GTK_STATUSBAR(CddbStatusBar),CddbStatusBarContext,msg);
     g_free(msg);
 
@@ -3893,9 +3927,8 @@ gboolean Cddb_Set_Track_Infos_To_File_List (void)
                                            GTK_DIALOG_MODAL  | GTK_DIALOG_DESTROY_WITH_PARENT,
                                            GTK_MESSAGE_QUESTION,
                                            GTK_BUTTONS_NONE,
-                                           _("You are applying %d lines of the CDDB results to %d lines in the list of files"),
-                                           rows_to_loop,
-                                           file_selectedcount);
+                                           "%s",
+                                           _("The number of CDDB results does not match the number of selected files"));
         gtk_dialog_add_buttons(GTK_DIALOG(msgdialog),GTK_STOCK_CANCEL,GTK_RESPONSE_CANCEL,GTK_STOCK_APPLY,GTK_RESPONSE_APPLY, NULL);
         gtk_message_dialog_format_secondary_text(GTK_MESSAGE_DIALOG(msgdialog),"%s","Do you want to continue?");
         gtk_window_set_title(GTK_WINDOW(msgdialog),_("Write Tag from CDDBâ"));
diff --git a/src/easytag.c b/src/easytag.c
index 952f7cb..208bde0 100644
--- a/src/easytag.c
+++ b/src/easytag.c
@@ -192,7 +192,7 @@ int main (int argc, char *argv[])
     INIT_DIRECTORY = NULL;
 
     /* Starting messages */
-    Log_Print(LOG_OK,_("Starting EasyTAG %s (PId: %d)â"),PACKAGE_VERSION,getpid());
+    Log_Print(LOG_OK,_("Starting EasyTAG version %s (PID: %d)â"),PACKAGE_VERSION,getpid());
 #ifdef ENABLE_MP3
     Log_Print(LOG_OK,_("Currently using libid3tag version %sâ"), ID3_VERSION);
 #endif
@@ -204,9 +204,9 @@ int main (int argc, char *argv[])
 
 #ifdef WIN32
     if (g_getenv("EASYTAGLANG"))
-        Log_Print(LOG_OK,_("Variable EASYTAGLANG defined. Setting locale : '%s'"),g_getenv("EASYTAGLANG"));
+        Log_Print(LOG_OK,_("Variable EASYTAGLANG defined. Setting locale: '%s'"),g_getenv("EASYTAGLANG"));
     else
-        Log_Print(LOG_OK,_("Setting locale : '%s'"),g_getenv("LANG"));
+        Log_Print(LOG_OK,_("Setting locale: '%s'"),g_getenv("LANG"));
 #endif
 
     if (get_locale())
@@ -227,8 +227,8 @@ int main (int argc, char *argv[])
         if ( (strcmp(argv[1],"--version")==0) || (strcmp(argv[1],"-v")==0) ) // Query version
         {
             g_print(_("%s %s by %s (compiled %s, %s)\n"),APPNAME,PACKAGE_VERSION,AUTHOR,__TIME__,__DATE__);
-            g_print(_("E-mail: %s"),EMAIL"\n");
-            g_print(_("Web Page: %s"),WEBPAGE"\n");
+            g_print(_("Email: %s"),EMAIL"\n");
+            g_print(_("Web Page: %s"),PACKAGE_URL"\n");
             exit (0);
         }else if ( (strcmp(argv[1],"--help")==0) || (strcmp(argv[1],"-h")==0) ) // Query help
         {
@@ -471,7 +471,7 @@ GtkWidget *Create_File_Area (void)
     /* Access status icon */
     ReadOnlyStatusIconBox = Create_Pixmap_Icon_With_Event_Box("easytag-read-only");
     gtk_box_pack_start(GTK_BOX(HBox),ReadOnlyStatusIconBox,FALSE,FALSE,0);
-    gtk_widget_set_tooltip_text(ReadOnlyStatusIconBox,_("Read Only File"));
+    gtk_widget_set_tooltip_text(ReadOnlyStatusIconBox,_("Read-only File"));
     BrokenStatusIconBox = Create_Pixmap_Icon_With_Event_Box(GTK_STOCK_MISSING_IMAGE);
     gtk_box_pack_start(GTK_BOX(HBox),BrokenStatusIconBox,FALSE,FALSE,0);
     gtk_widget_set_tooltip_text(BrokenStatusIconBox,_("File Link Broken"));
@@ -488,23 +488,25 @@ GtkWidget *Create_File_Area (void)
     gtk_table_set_row_spacings(GTK_TABLE(HeaderInfosTable),1);
     gtk_table_set_col_spacings(GTK_TABLE(HeaderInfosTable),2);
 
-    VersionLabel = gtk_label_new(_("MPEG"));
+    VersionLabel = gtk_label_new(_("Encoder:"));
     gtk_table_attach_defaults(GTK_TABLE(HeaderInfosTable),VersionLabel,0,1,0,1);
-    VersionValueLabel = gtk_label_new(_("?, Layer ?"));
+    VersionValueLabel = gtk_label_new("");
     gtk_table_attach_defaults(GTK_TABLE(HeaderInfosTable),VersionValueLabel,1,2,0,1);
     gtk_misc_set_alignment(GTK_MISC(VersionLabel),1,0.5);
     gtk_misc_set_alignment(GTK_MISC(VersionValueLabel),0,0.5);
 
     BitrateLabel = gtk_label_new(_("Bitrate:"));
     gtk_table_attach_defaults(GTK_TABLE(HeaderInfosTable),BitrateLabel,0,1,1,2);
-    BitrateValueLabel = gtk_label_new(_("? kb/s"));
+    BitrateValueLabel = gtk_label_new("");
     gtk_table_attach_defaults(GTK_TABLE(HeaderInfosTable),BitrateValueLabel,1,2,1,2);
     gtk_misc_set_alignment(GTK_MISC(BitrateLabel),1,0.5);
     gtk_misc_set_alignment(GTK_MISC(BitrateValueLabel),0,0.5);
 
-    SampleRateLabel = gtk_label_new(_("Freq:"));
+    /* Translators: Please try to keep this string as short as possible as it
+     * is shown in a narrow column. */
+    SampleRateLabel = gtk_label_new(_("Freq.:"));
     gtk_table_attach_defaults(GTK_TABLE(HeaderInfosTable),SampleRateLabel,0,1,2,3);
-    SampleRateValueLabel = gtk_label_new(_("? Hz"));
+    SampleRateValueLabel = gtk_label_new("");
     gtk_table_attach_defaults(GTK_TABLE(HeaderInfosTable),SampleRateValueLabel,1,2,2,3);
     gtk_misc_set_alignment(GTK_MISC(SampleRateLabel),1,0.5);
     gtk_misc_set_alignment(GTK_MISC(SampleRateValueLabel),0,0.5);
@@ -514,21 +516,21 @@ GtkWidget *Create_File_Area (void)
 
     ModeLabel = gtk_label_new(_("Mode:"));
     gtk_table_attach_defaults(GTK_TABLE(HeaderInfosTable),ModeLabel,3,4,0,1);
-    ModeValueLabel = gtk_label_new(_("?"));
+    ModeValueLabel = gtk_label_new("");
     gtk_table_attach_defaults(GTK_TABLE(HeaderInfosTable),ModeValueLabel,4,5,0,1);
     gtk_misc_set_alignment(GTK_MISC(ModeLabel),1,0.5);
     gtk_misc_set_alignment(GTK_MISC(ModeValueLabel),0,0.5);
 
     SizeLabel = gtk_label_new(_("Size:"));
     gtk_table_attach_defaults(GTK_TABLE(HeaderInfosTable),SizeLabel,3,4,1,2);
-    SizeValueLabel = gtk_label_new(_("? kb"));
+    SizeValueLabel = gtk_label_new("");
     gtk_table_attach_defaults(GTK_TABLE(HeaderInfosTable),SizeValueLabel,4,5,1,2);
     gtk_misc_set_alignment(GTK_MISC(SizeLabel),1,0.5);
     gtk_misc_set_alignment(GTK_MISC(SizeValueLabel),0,0.5);
 
-    DurationLabel = gtk_label_new(_("Time:"));
+    DurationLabel = gtk_label_new(_("Duration:"));
     gtk_table_attach_defaults(GTK_TABLE(HeaderInfosTable),DurationLabel,3,4,2,3);
-    DurationValueLabel = gtk_label_new(_("?"));
+    DurationValueLabel = gtk_label_new("");
     gtk_table_attach_defaults(GTK_TABLE(HeaderInfosTable),DurationValueLabel,4,5,2,3);
     gtk_misc_set_alignment(GTK_MISC(DurationLabel),1,0.5);
     gtk_misc_set_alignment(GTK_MISC(DurationValueLabel),0,0.5);
@@ -640,7 +642,7 @@ GtkWidget *Create_Tag_Area (void)
     g_object_set_data(G_OBJECT(ArtistEntry),"MButtonName",ArtistMButton);
 
     /* Album Artist */
-    AlbumArtistLabel = gtk_label_new(_("Album Artist:"));
+    AlbumArtistLabel = gtk_label_new(_("Album artist:"));
     gtk_table_attach(GTK_TABLE(Table),AlbumArtistLabel,0,1,2,3,GTK_FILL,GTK_FILL,TablePadding,TablePadding);
     gtk_misc_set_alignment(GTK_MISC(AlbumArtistLabel),1,0.5);
 
@@ -873,8 +875,9 @@ GtkWidget *Create_Tag_Area (void)
     g_object_set_data(G_OBJECT(ComposerEntry),"MButtonName",ComposerMButton);
 
 
-    /* Original Artist / Performer */
-    OrigArtistLabel = gtk_label_new(_("Orig. Artist:"));
+    /* Translators: Original Artist / Performer. Please try to keep this string
+     * as short as possible, as it must fit into a narrow column. */
+    OrigArtistLabel = gtk_label_new(_("Orig. artist:"));
     gtk_table_attach(GTK_TABLE(Table),OrigArtistLabel,0,1,8,9,GTK_FILL,GTK_FILL,TablePadding,TablePadding);
     gtk_misc_set_alignment(GTK_MISC(OrigArtistLabel),1,0.5);
 
@@ -3173,8 +3176,6 @@ gboolean Rename_File (ET_File *ETFile, gboolean hide_msgbox)
 
                 /* Removing directories failed */
                 dirname_cur_utf8 = filename_to_display(dirname_cur);
-                msg = g_strdup_printf(_("Can't remove old directory\n'%s'!\n(%s)"),
-                                      dirname_cur_utf8,g_strerror(errno));
                 if (!hide_msgbox)
                 {
                     msgdialog = gtk_message_dialog_new(GTK_WINDOW(MainWindow),
@@ -3209,8 +3210,6 @@ gboolean Rename_File (ET_File *ETFile, gboolean hide_msgbox)
             GtkWidget *msgdialog;
 
             /* Moving file has failed */
-            msg = g_strdup_printf(_("Can't move file '%s'\n to \n'%s'!\n(%s)"),
-                                  cur_basename_utf8,new_basename_utf8,g_strerror(errno));
             if (!hide_msgbox)
             {
                 msgdialog = gtk_message_dialog_new(GTK_WINDOW(MainWindow),
@@ -3445,7 +3444,6 @@ gboolean Read_Directory (gchar *path_real)
 {
     DIR   *dir;
     gchar *msg;
-    gchar *tmp;
     gchar  progress_bar_text[30];
     guint  nbrfile = 0;
     double fraction;
@@ -3598,9 +3596,9 @@ gboolean Read_Directory (gchar *path_real)
             gtk_label_set_text(GTK_LABEL(FileIndex),"0/0:");
 
 
-        tmp = g_strdup_printf(_("%u file(s)"),0); // See in ET_Display_Filename_To_UI
-        Browser_Label_Set_Text(tmp);
-        g_free(tmp);
+
+	/* Translators: No files, as in "0 files". */
+        Browser_Label_Set_Text(_("No files")); /* See in ET_Display_Filename_To_UI */
 
         /* Prepare message for the status bar */
         if (BROWSE_SUBDIR)
@@ -4423,14 +4421,14 @@ void Clear_Header_Fields (void)
     if (!VersionValueLabel) return;
 
     /* Default values are MPs data */
-    gtk_label_set_text(GTK_LABEL(VersionLabel),        _("MPEG"));
-    gtk_label_set_text(GTK_LABEL(VersionValueLabel),   _("?, Layer ?"));
-    gtk_label_set_text(GTK_LABEL(BitrateValueLabel),   _("? kb/s"));
-    gtk_label_set_text(GTK_LABEL(SampleRateValueLabel),_("? Hz"));
+    gtk_label_set_text(GTK_LABEL(VersionLabel),        _("Encoder:"));
+    gtk_label_set_text(GTK_LABEL(VersionValueLabel),   "");
+    gtk_label_set_text(GTK_LABEL(BitrateValueLabel),   "");
+    gtk_label_set_text(GTK_LABEL(SampleRateValueLabel),"");
     gtk_label_set_text(GTK_LABEL(ModeLabel),           _("Mode:"));
-    gtk_label_set_text(GTK_LABEL(ModeValueLabel),      _("?"));
-    gtk_label_set_text(GTK_LABEL(SizeValueLabel),      _("?"));
-    gtk_label_set_text(GTK_LABEL(DurationValueLabel),  _("?"));
+    gtk_label_set_text(GTK_LABEL(ModeValueLabel),      "");
+    gtk_label_set_text(GTK_LABEL(SizeValueLabel),      "");
+    gtk_label_set_text(GTK_LABEL(DurationValueLabel),  "");
 }
 
 
@@ -4682,21 +4680,22 @@ void Handle_Crash (gint signal_id)
 {
     //gchar commmand[256];
 
-    Log_Print(LOG_ERROR,_("EasyTAG %s: Abnormal exit! (PId: %d)."),PACKAGE_VERSION,getpid());
-    Log_Print(LOG_ERROR,_("Received signal %s (%d)\a"),signal_to_string(signal_id),signal_id);
+    Log_Print(LOG_ERROR,_("EasyTAG version %s: Abnormal exit! (PID: %d)."),PACKAGE_VERSION,getpid());
+    Log_Print(LOG_ERROR,_("Received signal %s (%d)"),signal_to_string(signal_id),signal_id);
 
-    Log_Print(LOG_ERROR,_("You have probably found a bug in EasyTAG. Please, send a bug "
-              "report with a gdb backtrace ('gdb easytag core' then 'bt' and "
-              "'l') and information to reproduce it to easytag gmail com"));
+    Log_Print(LOG_ERROR,_("You have probably found a bug in EasyTAG. Please, "
+                          "file a bug report with a gdb backtrace ('gdb "
+			  "easytag core' then 'bt' and 'l') and information "
+			  "to reproduce it at: %s"),PACKAGE_BUGREPORT);
 
     // To send messages to the console...
-    g_print(_("EasyTAG %s: Abnormal exit! (PId: %d)."),PACKAGE_VERSION,getpid());
+    g_print(_("EasyTAG version %s: Abnormal exit! (PID: %d)."),PACKAGE_VERSION,getpid());
     g_print("\n");
     g_print(_("Received signal %s (%d)\a"),signal_to_string(signal_id),signal_id);
     g_print("\n");
-    g_print(_("You have probably found a bug in EasyTAG. Please, send a bug "
+    g_print(_("You have probably found a bug in EasyTAG. Please, file a bug "
             "report with a gdb backtrace ('gdb easytag core' then 'bt' and "
-            "'l') and information to reproduce it to easytag gmail com"));
+            "'l') and information to reproduce it at: %s"),PACKAGE_BUGREPORT);
     g_print("\n");
 
     signal(signal_id,SIG_DFL); // Let the OS handle recursive seg faults
diff --git a/src/et_core.c b/src/et_core.c
index 64a8f92..ca8c893 100644
--- a/src/et_core.c
+++ b/src/et_core.c
@@ -2779,7 +2779,7 @@ void ET_Display_Filename_To_UI (ET_File *ETFile)
     Browser_Entry_Set_Text(dirname_utf8);
 
     // And refresh the number of files in this directory
-    text = g_strdup_printf(_("%u file(s)"),ET_Get_Number_Of_Files_In_Directory(dirname_utf8));
+    text = g_strdup_printf(ngettext("One file","%u files",ET_Get_Number_Of_Files_In_Directory(dirname_utf8)),ET_Get_Number_Of_Files_In_Directory(dirname_utf8));
     Browser_Label_Set_Text(text);
     g_free(dirname_utf8);
     g_free(text);
diff --git a/src/misc.c b/src/misc.c
index 7f559ec..c350bb9 100644
--- a/src/misc.c
+++ b/src/misc.c
@@ -1370,7 +1370,7 @@ void Open_Write_Playlist_Window (void)
         GTK_RADIO_BUTTON(playlist_content_none),_("Write info using filename"));
     gtk_box_pack_start(GTK_BOX(vbox),playlist_content_filename,FALSE,FALSE,0);
 
-    playlist_content_mask = gtk_radio_button_new_with_label_from_widget(GTK_RADIO_BUTTON(playlist_content_none), _("Write info using :"));
+    playlist_content_mask = gtk_radio_button_new_with_label_from_widget(GTK_RADIO_BUTTON(playlist_content_none), _("Write info using:"));
     hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL,0);
     gtk_box_pack_start(GTK_BOX(vbox),hbox,FALSE,FALSE,0);
     gtk_box_pack_start(GTK_BOX(hbox),playlist_content_mask,FALSE,FALSE,0);
@@ -1926,7 +1926,7 @@ void Open_Search_File_Window (void)
                                          N_("Genre"),
                                          N_("Comment"),
                                          N_("Composer"),
-                                         N_("Orig. Artist"),
+                                         N_("Original Artist"),
                                          N_("Copyright"),
                                          N_("URL"),
                                          N_("Encoded by")
@@ -1967,7 +1967,7 @@ void Open_Search_File_Window (void)
     else
         gtk_list_store_clear(SearchStringModel);
 
-    Label = gtk_label_new(_("Search :"));
+    Label = gtk_label_new(_("Search:"));
     gtk_misc_set_alignment(GTK_MISC(Label),1.0,0.5);
     gtk_table_attach(GTK_TABLE(Table),Label,0,1,0,1,GTK_FILL,GTK_FILL,0,0);
     SearchStringCombo = gtk_combo_box_new_with_model_and_entry(GTK_TREE_MODEL(SearchStringModel));
@@ -1984,11 +1984,17 @@ void Open_Search_File_Window (void)
     gtk_editable_paste_clipboard(GTK_EDITABLE(gtk_bin_get_child(GTK_BIN(SearchStringCombo))));
 
     // Where...
-    Label = gtk_label_new(_("In :"));
+    Label = gtk_label_new(_("In:"));
     gtk_misc_set_alignment(GTK_MISC(Label),1.0,0.5);
     gtk_table_attach(GTK_TABLE(Table),Label,0,1,1,2,GTK_FILL,GTK_FILL,0,0);
-    SearchInFilename = gtk_check_button_new_with_label(_("the File Name"));
-    // Note : label changed to "the Tag" (to be the only one) to fix a Hungarian grammatical problem (which uses one word to say "in the tag" like here)
+    /* Translators: This option is for the previous 'in' option. For instance,
+     * translate this as "Search" "In:" "the Filename". */
+    SearchInFilename = gtk_check_button_new_with_label(_("the Filename"));
+    /* Translators: This option is for the previous 'in' option. For instance,
+     * translate this as "Search" "In:" "the Tag".
+     * Note: label changed to "the Tag" (to be the only one) to fix a Hungarian
+     * grammatical problem (which uses one word to say "in the tag" like here)
+     */
     SearchInTag = gtk_check_button_new_with_label(_("the Tag"));
     gtk_table_attach(GTK_TABLE(Table),SearchInFilename,1,2,1,2,GTK_FILL,GTK_FILL,0,0);
     gtk_table_attach(GTK_TABLE(Table),SearchInTag,2,3,1,2,GTK_FILL,GTK_FILL,0,0);
diff --git a/src/prefs.c b/src/prefs.c
index 26fc042..e8cf557 100644
--- a/src/prefs.c
+++ b/src/prefs.c
@@ -161,7 +161,7 @@ void Open_OptionsWindow (void)
     gtk_box_pack_start(GTK_BOX(vbox),HBox,FALSE,FALSE,0);
 
     // Label
-    Label = gtk_label_new(_("Default directory :"));
+    Label = gtk_label_new(_("Default directory:"));
     gtk_box_pack_start(GTK_BOX(HBox),Label,FALSE,FALSE,0);
 
     // Combo
@@ -259,7 +259,7 @@ void Open_OptionsWindow (void)
     hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL,2);
     gtk_box_pack_start(GTK_BOX(vbox),hbox,FALSE,FALSE,0);
     gtk_container_set_border_width(GTK_CONTAINER(hbox), 2);
-    Label = gtk_label_new(_("Display changed files in list using :"));
+    Label = gtk_label_new(_("Display changed files in list using:"));
     gtk_box_pack_start(GTK_BOX(hbox),Label,FALSE,FALSE,0);
 
     ChangedFilesDisplayedToRed = gtk_radio_button_new_with_label(NULL,_("Red color"));
@@ -284,7 +284,7 @@ void Open_OptionsWindow (void)
     gtk_box_pack_start(GTK_BOX(vbox),hbox,FALSE,FALSE,0);
     gtk_container_set_border_width(GTK_CONTAINER(hbox), 2);
     /* Sorting method */
-    Label = gtk_label_new(_("Sort the file list by :"));
+    Label = gtk_label_new(_("Sort the file list by:"));
     gtk_box_pack_start(GTK_BOX(hbox),Label,FALSE,FALSE,0);
 
     EventBox = gtk_event_box_new();
@@ -383,7 +383,7 @@ void Open_OptionsWindow (void)
     hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL,2);
     gtk_container_add(GTK_CONTAINER(Frame),hbox);
     gtk_container_set_border_width(GTK_CONTAINER(hbox), 4);
-    Label = gtk_label_new (_("Player to run :"));
+    Label = gtk_label_new (_("Player to run:"));
     gtk_box_pack_start(GTK_BOX(hbox),Label,FALSE,FALSE,0);
     FilePlayerCombo = gtk_combo_box_new_with_model_and_entry(GTK_TREE_MODEL(FilePlayerModel));
     gtk_combo_box_set_entry_text_column(GTK_COMBO_BOX(FilePlayerCombo),MISC_COMBO_TEXT);
@@ -424,7 +424,7 @@ void Open_OptionsWindow (void)
     hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL,2);
     gtk_box_pack_start(GTK_BOX(vbox),hbox,FALSE,FALSE,0);
     gtk_container_set_border_width(GTK_CONTAINER(hbox), 4);
-    Label = gtk_label_new (_("Max number of lines :"));
+    Label = gtk_label_new (_("Max number of lines:"));
     gtk_box_pack_start(GTK_BOX(hbox),Label,FALSE,FALSE,0);
     
     LogMaxLinesSpinButton = gtk_spin_button_new_with_range(10.0,1500.0,10.0);
@@ -471,7 +471,7 @@ void Open_OptionsWindow (void)
     gtk_box_pack_start(GTK_BOX(vbox),hbox,FALSE,FALSE,0);
     gtk_container_set_border_width(GTK_CONTAINER(hbox), 2);
     /* Extension case (lower/upper?) */
-    Label = gtk_label_new(_("Convert filename extension to :"));
+    Label = gtk_label_new(_("Convert filename extension to:"));
     gtk_box_pack_start(GTK_BOX(hbox),Label,FALSE,FALSE,0);
 
     FilenameExtensionLowerCase = gtk_radio_button_new_with_label(NULL,_("Lower Case"));
@@ -593,11 +593,11 @@ void Open_OptionsWindow (void)
     hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL,0);
     gtk_box_pack_start(GTK_BOX(vbox),hbox,FALSE,FALSE,0);
 
-    NumberTrackFormated = gtk_check_button_new_with_label(_("Write the track field with the following number of digits :"));
+    NumberTrackFormated = gtk_check_button_new_with_label(_("Write the track field with the following number of digits:"));
     gtk_box_pack_start(GTK_BOX(hbox),NumberTrackFormated,FALSE,FALSE,0);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(NumberTrackFormated),NUMBER_TRACK_FORMATED);
     gtk_widget_set_tooltip_text(NumberTrackFormated,_("If activated, the track field is written using "
-        "the number '0' as padding to obtain a number with 'n' digits (Ex. with two digits : '05', "
+        "the number '0' as padding to obtain a number with 'n' digits (for example, with two digits: '05', "
         "'09', '10' â). Else it keeps the 'raw' track value."));
 
     NumberTrackFormatedSpinButton = gtk_spin_button_new_with_range(2.0,6.0,1.0);
@@ -611,7 +611,7 @@ void Open_OptionsWindow (void)
     g_signal_connect_swapped(G_OBJECT(NumberTrackFormatedSpinButton),"changed",G_CALLBACK(Number_Track_Formated_Spin_Button_Changed),G_OBJECT(Label));
     g_signal_emit_by_name(G_OBJECT(NumberTrackFormatedSpinButton),"changed",NULL);
 
-    OggTagWriteXmmsComment = gtk_check_button_new_with_label(_("Ogg Vorbis Files : Write also the comment to the XMMS format"));
+    OggTagWriteXmmsComment = gtk_check_button_new_with_label(_("Ogg Vorbis Files: write also the comment in the XMMS format"));
     gtk_box_pack_start(GTK_BOX(vbox),OggTagWriteXmmsComment,FALSE,FALSE,0);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(OggTagWriteXmmsComment),OGG_TAG_WRITE_XMMS_COMMENT);
     gtk_widget_set_tooltip_text(OggTagWriteXmmsComment,_("XMMS doesn't make use of the right way to "
@@ -656,8 +656,7 @@ void Open_OptionsWindow (void)
     gtk_container_add(GTK_CONTAINER(Frame),Table);
     gtk_table_set_col_spacings(GTK_TABLE(Table),2);
     
-    Label = gtk_label_new(_("For Vorbis tags, selected fields will be split at"
-                "dashes and saved as separate tags"));
+    Label = gtk_label_new(_("For Vorbis tags, selected fields will be split at dashes and saved as separate tags"));
     gtk_table_attach(GTK_TABLE(Table),Label,0,2,0,1,GTK_FILL,GTK_FILL,0,1);
     gtk_misc_set_alignment(GTK_MISC(Label),0,0.5);
 
@@ -667,7 +666,7 @@ void Open_OptionsWindow (void)
     VorbisSplitFieldGenre = gtk_check_button_new_with_label(_("Genre"));
     VorbisSplitFieldComment = gtk_check_button_new_with_label(_("Comment"));
     VorbisSplitFieldComposer = gtk_check_button_new_with_label(_("Composer"));
-    VorbisSplitFieldOrigArtist = gtk_check_button_new_with_label(_("Orig. Artist"));
+    VorbisSplitFieldOrigArtist = gtk_check_button_new_with_label(_("Original artist"));
 
     gtk_table_attach(GTK_TABLE(Table),VorbisSplitFieldTitle,0,1,1,2,GTK_FILL,GTK_FILL,0,0);
     gtk_table_attach(GTK_TABLE(Table),VorbisSplitFieldArtist,0,1,2,3,GTK_FILL,GTK_FILL,0,0);
@@ -1407,7 +1406,7 @@ void Open_OptionsWindow (void)
     gtk_box_pack_start(GTK_BOX(vbox),CddbUseDLM,FALSE,FALSE,0);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(CddbUseDLM),CDDB_USE_DLM);
     gtk_widget_set_tooltip_text(CddbUseDLM,_("When activating this option, the "
-        "Levenshtein algorithm (DLM : Damerau-Levenshtein Metric) will be used "
+        "Levenshtein algorithm (DLM: Damerau-Levenshtein Metric) will be used "
         "to match the CDDB title against every file name in the current folder, "
         "and to select the best match. This will be used when selecting the "
         "corresponding audio file, or applying cddb results, instead of using "
diff --git a/src/scan.c b/src/scan.c
index 34999e6..c0582e7 100644
--- a/src/scan.c
+++ b/src/scan.c
@@ -2682,7 +2682,7 @@ void Open_ScannerWindow (gint scanner_type)
     gtk_box_pack_start(GTK_BOX(VBox),Separator,FALSE,FALSE,0);
 
     /* Group: character conversion */
-    ProcessFieldsConvertIntoSpace = gtk_check_button_new_with_label(_("Convert '_' and '%20' to ' '"));
+    ProcessFieldsConvertIntoSpace = gtk_check_button_new_with_label(_("Convert '_' and '%20' to spaces"));
     ProcessFieldsConvertSpace     = gtk_check_button_new_with_label(_("Convert ' ' to '_'"));
     gtk_box_pack_start(GTK_BOX(VBox),ProcessFieldsConvertIntoSpace,FALSE,FALSE,0);
     gtk_box_pack_start(GTK_BOX(VBox),ProcessFieldsConvertSpace,    FALSE,FALSE,0);
diff --git a/src/vcedit.c b/src/vcedit.c
index b49e442..7c4d552 100644
--- a/src/vcedit.c
+++ b/src/vcedit.c
@@ -402,7 +402,7 @@ int vcedit_open_callbacks(vcedit_state *state, void *in,
                                     _speex_unpack_comment(state->vc,&opb);
                                     break;
                                 default:
-                                    state->lasterror = _("Need to save extra headers - TODO!!");
+                                    state->lasterror = _("Need to save extra headers"); /* FIXME. */
                                     goto err;
                                     break;
                             }



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/bar.c b/src/bar.c
index 55e10f9..bfa40db 100644
--- a/src/bar.c
+++ b/src/bar.c
@@ -232,7 +232,7 @@ void Create_UI (GtkWidget **ppmenubar, GtkWidget **pptoolbar)
 
         { MENU_MISC,                NULL,                   _("_Misc"),                             NULL,         NULL,                                 NULL },
         { AM_SEARCH_FILE,           GTK_STOCK_FIND,         _("Search _File(s)â"),               "<Control>F", _("Search File(s)â"),               G_CALLBACK(Open_Search_File_Window) },
-        { AM_CDDB_SEARCH,           GTK_STOCK_CDROM,        _("CD Data _Base Searchâ"),          "<Control>B", _("CDDB Searchâ"),                 G_CALLBACK(Open_Cddb_Window) },
+        { AM_CDDB_SEARCH,           GTK_STOCK_CDROM,        _("CD Data_base Searchâ"),          "<Control>B", _("CDDB Searchâ"),                 G_CALLBACK(Open_Cddb_Window) },
         { AM_FILENAME_FROM_TXT,     GTK_STOCK_OPEN,         _("Load Filenames from TXTâ"),       "<Alt>T",     _("Load Filenames from TXTâ"),     G_CALLBACK(Open_Load_Filename_Window) },
         { AM_WRITE_PLAYLIST,        GTK_STOCK_SAVE_AS,      _("Write Playlistâ"),                "<Alt>W",     _("Write Playlistâ"),              G_CALLBACK(Open_Write_Playlist_Window) },
         { AM_RUN_AUDIO_PLAYER,      "easytag-sound",        _("Run Audio Player"),                  "<Alt>X",     _("Run Audio Player"),                G_CALLBACK(Run_Audio_Player_Using_Selection) },
@@ -268,8 +268,8 @@ void Create_UI (GtkWidget **ppmenubar, GtkWidget **pptoolbar)
 
     GtkToggleActionEntry ToggleActionEntries[] =
     {
-        //{ AM_BROWSE_SUBDIR,      GTK_STOCK_INDEX,        _("Browse _Sub-directories"),                         NULL, _("Browse _Sub-directories"),                         NULL,                                    FALSE },
-        { AM_BROWSE_SUBDIR,      NULL,                   _("Browse _Sub-directories"),                         NULL, _("Browse _Sub-directories"),                         NULL,                                    BROWSE_SUBDIR },
+        //{ AM_BROWSE_SUBDIR,      GTK_STOCK_INDEX,        _("Browse _Subdirectories"),                         NULL, _("Browse _Sub-directories"),                         NULL,                                    FALSE },
+        { AM_BROWSE_SUBDIR,      NULL,                   _("Browse _Subdirectories"),                         NULL, _("Browse _Subdirectories"),                         NULL,                                    BROWSE_SUBDIR },
 #ifndef WIN32 // No sense here for Win32, "hidden" means : starts with a '.'
         //{ AM_BROWSER_HIDDEN_DIR, NULL,                   _("Show Hidden Directories"),                         NULL, _("Show Hidden Directories"),                         G_CALLBACK(Browser_Tree_Rebuild),     FALSE },
         { AM_BROWSER_HIDDEN_DIR, NULL,                   _("Show Hidden Directories"),                         NULL, _("Show Hidden Directories"),                         G_CALLBACK(Browser_Tree_Rebuild),     BROWSE_HIDDEN_DIR },